#!/usr/bin/env python3
"""
ONEX Input State Configuration.

Strongly-typed configuration class for ONEX input state.
"""


class ModelConfig:
    """Pydantic model configuration for ONEX compliance."""
