"""
ModelCredentialsAnalysis: Credentials strength analysis results.

This model provides structured credentials analysis without using Any types.
"""

from .model_credentialsanalysis import ModelCredentialsAnalysis, ModelManagerAssessment

__all__ = [
    "ModelCredentialsAnalysis",
    "ModelManagerAssessment",
]
