# SPDX-FileCopyrightText: 2025 OmniNode Team <info@omninode.ai>
#
# SPDX-License-Identifier: Apache-2.0
"""
Handler protocols module.

This module provides protocols for handler type resolution.
"""

from omnibase_core.protocols.handlers.protocol_handler_type_resolver import (
    ProtocolHandlerTypeResolver,
)

__all__ = [
    "ProtocolHandlerTypeResolver",
]
